@@ -15,7 +15,7 @@ import math
 import numpy as np
 
 class AugmentoForecasterParalleLauncher():
-    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon', underlying=None, frequence=None, db_path_suffix = '_forecaster.sqlite', ss=[10], ns=[21], s_evals = [5], calibration_steps=[1000], optimize_thresholds=[True], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
+    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon', underlying=None, frequence=None, db_path_suffix = '_forecaster.sqlite', advanced_features = [False],ss=[10], ns=[21], s_evals = [5], calibration_steps=[1000],  signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
         self.starting_date = starting_date
         self.running_date = running_date
         self.args = []
@@ -23,15 +23,16 @@ class AugmentoForecasterParalleLauncher():
         self.counter = 1
         self.seed = 0
         self.mapping_keys={}
-        for s in ss:
-            for n in ns:
-                for s_eval in s_evals:
-                    for calibration_step in calibration_steps:
-                        for signal_type, params  in signal_idiosyncratic_paramaters.items():
-                            for param in params:
-                                self.args.append((self,self.seed,n,s,s_eval,calibration_step,signal_type,json.dumps(param, sort_keys=True)))
-                                self.key_args.append((self.seed,n,s,s_eval,calibration_step,signal_type,json.dumps(param, sort_keys=True)))
-                                self.counter = self.counter + 1
+        for adv_feat in advanced_features:
+            for s in ss:
+                for n in ns:
+                    for s_eval in s_evals:
+                        for calibration_step in calibration_steps:
+                            for signal_type, params  in signal_idiosyncratic_paramaters.items():
+                                for param in params:
+                                    self.args.append((self,self.seed,adv_feat,n,s,s_eval,calibration_step,signal_type,json.dumps(param, sort_keys=True)))
+                                    self.key_args.append((self.seed,adv_feat,n,s,s_eval,calibration_step,signal_type,json.dumps(param, sort_keys=True)))
+                                    self.counter = self.counter + 1
         self.key_args.sort()
         self.counter = 1
         for me_arg in self.key_args:
@@ -71,10 +72,11 @@ class AugmentoForecasterParalleLauncher():
         self.empty_runs_to_investigate = []
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
 
-    def create_saving_key(self, seed, n, s, s_eval, calibration_step, signal_type, idios_string):
+    def create_saving_key(self, seed, adv_feat, n, s, s_eval, calibration_step, signal_type, idios_string):
         idios = json.loads(idios_string)
         common_params = {
             'seed': seed,
+            'adv_feat':adv_feat,
             'n': n,
             's': s,
             's_eval': s_eval,
